﻿using System.Linq.Expressions;
using XF.Domain.Authentications;
using XF.Domain.Dependency;
using XF.Domain.Entities;

namespace Hotline.Repository.SqlSugar.DataPermissions;

public class DataPermissionFilterBuilder : IDataPermissionFilterBuilder, IScopeDependency
{
    private readonly ISessionContext _sessionContext;
    private readonly IDataPermissionManager _dataPermissionManager;

    public DataPermissionFilterBuilder(ISessionContext sessionContext, IDataPermissionManager dataPermissionManager)
    {
        _sessionContext = sessionContext;
        _dataPermissionManager = dataPermissionManager;
    }

    public Expression<Func<TEntity, bool>> Build<TEntity>() where TEntity : class, IEntity<string>, IDataPermission, new()
    {
        var userId = _sessionContext.RequiredUserId;
        var scheme = _dataPermissionManager.GetQueryFilter<TEntity>(_sessionContext);
        switch (scheme.QueryFilter)
        {
            case EQueryFilter.CreatorOnly:
                return d => d.CreateUserId == userId;
            case EQueryFilter.SelfAndSubDepartment:
                return d => d.OrgCode == scheme.OrgCode;//todo
            default:
                throw new ArgumentOutOfRangeException();
        }
    }
}